@@ -27,9 +27,17 @@ extern "C"
 {
 #endif
 
-  int pack_table (int *base, int key_num, int key_size, int ptr_size,
-		  int max_depth, int tab_width, char **name,
-		  char *key_type_name, char *table_name, char *macro_name,
+#define packtab_version 2
+
+  int pack_table (int *base,
+		  int key_num,
+		  int key_size,
+		  int max_depth,
+		  int tab_width,
+		  char **name,
+		  char *key_type_name,
+		  char *table_name,
+		  char *macro_name,
 		  FILE * out);
 
 #ifdef	__cplusplus
